@@ -46,26 +46,6 @@ pref("extensions.activeThemeID", "tr-light@treuchtlingen.de");
 // default = 8. -1 allows Firefox to use as many as it wants
 // user_pref("dom.ipc.processCount", 4);
 
-// set Proxy settings
-
-// Proxy Pac
-//pref("network.proxy.type", 2);
-//pref("network.proxy.autoconfig_url", "file:///etc/treuchtlingen/proxy.pac");
-//pref("signon.autologin.proxy", true);
-
-// Use firefox settings to configure proxy
-pref("network.proxy.ftp", "proxy.dmz.treuchtlingen.stadt");
-pref("network.proxy.ftp_port", 3128);
-pref("network.proxy.http", "proxy.dmz.treuchtlingen.stadt");
-pref("network.proxy.http_port", 3128);
-pref("network.proxy.share_proxy_settings", true);
-pref("network.proxy.socks", "proxy.dmz.treuchtlingen.stadt");
-pref("network.proxy.socks_port", 3128);
-pref("network.proxy.ssl", "proxy.dmz.treuchtlingen.stadt");
-pref("network.proxy.ssl_port", 3128);
-pref("network.proxy.type", 1);
-
-pref("network.proxy.no_proxies_on", ".stadt, 192.168.0.0/16, up, 157.40.1.0/24, gis-auskunft.treuchtlingen.eu");
 pref("media.peerconnection.ice.proxy_only_if_behind_proxy", true);
 
 pref("signon.management.page.fileImport.enabled", true);
